﻿using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.System;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Input;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "CommandBar 엘리먼트 사용하기";

            #endregion

            this.addButton.KeyboardAccelerators.Add
            (
                new KeyboardAccelerator()
                {
                    Key       = VirtualKey.A,
                    Modifiers = VirtualKeyModifiers.Control
                }
            );

            this.editButton.KeyboardAccelerators.Add
            (
                new KeyboardAccelerator()
                {
                    Key       = VirtualKey.E,
                    Modifiers = VirtualKeyModifiers.Control
                }
            );

            this.shareButton.KeyboardAccelerators.Add
            (
                new KeyboardAccelerator()
                {
                    Key = VirtualKey.F4
                }
            );
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 앱바 버튼 클릭시 처리하기 - appBarButton_Click(sender, e)

        /// <summary>
        /// 앱바 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void appBarButton_Click(object sender, RoutedEventArgs e)
        {
            AppBarButton button = sender as AppBarButton;

            this.textBlock.Text = $"클릭했습니다 : {button.Label}";
        }

        #endregion
        #region 보조 명령바 표시 버튼 클릭시 처리하기 - openButton_Click(sender, e)

        /// <summary>
        /// 보조 명령바 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void openButton_Click(object sender, RoutedEventArgs e)
        {
            this.commandBar.IsOpen   = true;
            this.commandBar.IsSticky = true;
        }

        #endregion
        #region 보조 명령바 닫기 버튼 클릭시 처리하기 - closeButton_Click(sender, e)

        /// <summary>
        /// 보조 명령바 닫기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void closeButton_Click(object sender, RoutedEventArgs e)
        {
            this.commandBar.IsOpen   = false;
            this.commandBar.IsSticky = false;
        }

        #endregion
        #region 보조 명령 추가 버튼 클릭시 처리하기 - addSecondaryCommandButton_Click(sender, e)

        /// <summary>
        /// 보조 명령 추가 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void addSecondaryCommandButton_Click(object sender, RoutedEventArgs e)
        {
            if(this.commandBar.SecondaryCommands.Count == 1)
            {
                AppBarButton newButton = new AppBarButton
                {
                    Icon  = new SymbolIcon(Symbol.Add),
                    Label = "버튼 1"
                };

                newButton.KeyboardAccelerators.Add
                (
                    new KeyboardAccelerator()
                    {
                        Key       = VirtualKey.N,
                        Modifiers = VirtualKeyModifiers.Control
                    }
                );

                this.commandBar.SecondaryCommands.Add(newButton);

                newButton = new AppBarButton
                {
                    Icon  = new SymbolIcon(Symbol.Delete),
                    Label = "버튼 2"
                };

                this.commandBar.SecondaryCommands.Add(newButton);

                newButton.KeyboardAccelerators.Add
                (
                    new KeyboardAccelerator()
                    {
                        Key = VirtualKey.Delete
                    }
                );

                this.commandBar.SecondaryCommands.Add(new AppBarSeparator());

                newButton = new AppBarButton
                {
                    Icon  = new SymbolIcon(Symbol.FontDecrease),
                    Label = "버튼 3"
                };

                newButton.KeyboardAccelerators.Add
                (
                    new KeyboardAccelerator()
                    {
                        Key       = VirtualKey.Subtract,
                        Modifiers = VirtualKeyModifiers.Control
                    }
                );

                this.commandBar.SecondaryCommands.Add(newButton);

                newButton = new AppBarButton
                {
                    Icon  = new SymbolIcon(Symbol.FontIncrease),
                    Label = "버튼 4"
                };

                newButton.KeyboardAccelerators.Add
                (
                    new KeyboardAccelerator()
                    {
                        Key       = VirtualKey.Add,
                        Modifiers = VirtualKeyModifiers.Control
                    }
                );

                this.commandBar.SecondaryCommands.Add(newButton);
            }
        }

        #endregion
        #region 보조 명령 제거 버튼 클릭시 처리하기 - removeSecondaryCommandButton_Click(sender, e)

        /// <summary>
        /// 보조 명령 제거 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void removeSecondaryCommandButton_Click(object sender, RoutedEventArgs e)
        {
            RemoveSecondaryCommand();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 보조 명령 제거하기 - RemoveSecondaryCommand()

        /// <summary>
        /// 보조 명령 제거하기
        /// </summary>
        private void RemoveSecondaryCommand()
        {
            while(this.commandBar.SecondaryCommands.Count > 1)
            {
                this.commandBar.SecondaryCommands.RemoveAt(this.commandBar.SecondaryCommands.Count - 1);
            }
        }

        #endregion
    }
}